<?php
/**
 * FotoGraphy functions and definitions
 *
 * @package FotoGraphy
 */

if ( ! function_exists( 'fotography_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function fotography_setup() {

	if ( ! isset( $content_width ) ) $content_width = 900;
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on FotoGraphy, use a find and replace
	 * to change 'fotography' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'fotography', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'fotography-thumb-view', 260, 260, true); 
	add_image_size( 'fotography-thumb-view-withslider', 290, 290, true); 
	add_image_size( 'fotography-thumb-view-blog', 210, 210, true); 
	add_image_size( 'fotography-bxslider', 930, 350, true); 
	//grid image cropt
	add_image_size( 'fotography-grid-small', 400, 400, true);
	add_image_size( 'fotography-grid-medium', 600, 300, true);
	add_image_size( 'fotography-grid-large', 600, 600, true);
	// Our Services 
	add_image_size( 'fotography-our-services', 640, 440, true);
	//
	add_image_size( 'fotography-sly', 1280, 720, true);
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'fotography' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',		
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'fotography_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // fotography_setup
add_action( 'after_setup_theme', 'fotography_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! function_exists( 'fotography_content_width' ) ) :
	function fotography_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'fotography_content_width', 640 );
	}
	add_action( 'after_setup_theme', 'fotography_content_width', 0 );
endif;
/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
if ( ! function_exists( 'fotography_widgets_init' ) ) :
function fotography_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Left Sidebar Widget Area', 'fotography' ),
		'id'            => 'fotography-left-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

    register_sidebar( array(
		'name'          => __( 'Right Sidebar Widget Area', 'fotography' ),
		'id'            => 'fotography-right-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'HomePage Left Widget Area', 'fotography' ),
		'id'            => 'fotography-home-left',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'HomePage Right Widget Area', 'fotography' ),
		'id'            => 'fotography-home-right',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'HomePage Instagram Widget Area', 'fotography' ),
		'id'            => 'fotography-home-instagram',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'Gallery Widget Area', 'fotography' ),
		'id'            => 'fotography-gallery-sidebar',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

    register_sidebar( array(
		'name'          => __( 'Footer Widget Area One', 'fotography' ),
		'id'            => 'fotography_footer_one',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Widget Area Two', 'fotography' ),
		'id'            => 'fotography_footer_two',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Widget Area Three', 'fotography' ),
		'id'            => 'fotography_footer_three',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );
    register_sidebar( array(
		'name'          => __( 'Footer Widget Area Four', 'fotography' ),
		'id'            => 'fotography_footer_four',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );

	register_sidebar( array(
		'name'          => __( 'Social Icon Widget Area Four', 'fotography' ),
		'id'            => 'fotography-social-icon',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="%2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );
    
}
add_action( 'widgets_init', 'fotography_widgets_init' );
endif;
/**
 * Enqueue scripts and styles.
 */
function fotography_scripts() {
	 /*****************************
	 * Use google fonts          **
	 ******************************/
	$query_args = array( 
	    'family' => 'Lato:300,400,700|Playfair+Display:400,700',
	);
	wp_enqueue_style( 'fotography-google-fonts', add_query_arg( $query_args, "//fonts.googleapis.com/css" ) );
	
    wp_enqueue_script( 'fotography-jquery-fitvids-js', get_template_directory_uri() . '/js/jquery.fitvids.js', array('jquery'), '20150906', true);

    wp_enqueue_script( 'fotography-jquery-slicknav', get_template_directory_uri() . '/js/jquery.slicknav.js', array('jquery'), '20150917', true);
    wp_enqueue_style('fotography-slicknav-css',get_template_directory_uri() . '/css/slicknav.css', true );
	
	//Superslides
	wp_enqueue_style('fotography-superslides-css',get_template_directory_uri() . '/css/superslides.css', true );
	wp_enqueue_script('fotography-jquery-easing-js',get_template_directory_uri() . '/js/jquery.easing.1.3.js', array('jquery'), '1.3', true );
	wp_enqueue_script('fotography-jquery-animate-enhanced-min',get_template_directory_uri() . '/js/jquery.animate-enhanced.min.js', array('jquery'), true );
	wp_enqueue_script('fotography-jquery-superslides',get_template_directory_uri() . '/js/jquery.superslides.js', array('jquery'), true );
	wp_enqueue_style( 'fotography-style', get_stylesheet_uri() );

//font-awesome
	wp_enqueue_style('fotography-font-awesome',get_template_directory_uri() . '/css/font-awesome.min.css',true );
	
	wp_enqueue_script('jquery');	
	wp_enqueue_script('fotography-isotope-pkgd-min-js',get_template_directory_uri() . '/js/isotope.pkgd.min.js', array(), '2.2.0', true );
	wp_enqueue_script('fotography-custom-js', get_template_directory_uri() . '/js/custom.js', array(), '', true );
	wp_enqueue_script( 'fotography-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'fotography-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	// Image Popup css
	wp_enqueue_style('fotography-prettyPhoto-css',get_template_directory_uri() . '/single/css/prettyPhoto.css');
	// Image Popup
	wp_enqueue_script( 'fotography-jquery-prettyPhoto-js', get_template_directory_uri() . '/single/js/jquery.prettyPhoto.js', array('jquery'), '20150705', true);
	
    wp_enqueue_script( 'fotography-jquery-sticky', get_template_directory_uri() . '/js/jquery.sticky.js', array('jquery'), '20150706', true);
    
    wp_enqueue_script( 'fotography-counterup', get_template_directory_uri() . '/js/counterup.js', array('jquery'), '20150706', true);

    wp_enqueue_script( 'fotography-waypoints', get_template_directory_uri() . '/js/waypoints.min.js', array('jquery'), '20150706', true);

    wp_enqueue_script( 'fotography-imagesloaded', get_template_directory_uri() . '/js/imagesloaded.js', array('jquery'), '20150706', true);
  
   
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

if(is_single())
{
// Folio View Script & Css
	wp_enqueue_style('fotography-lightGallerycss',get_template_directory_uri() . '/single/css/lightGallery.css');
	wp_enqueue_style('fotography-cusotm-single-css',get_template_directory_uri() . '/single/css/style.css');
    
// SLY Gallery
	global $post;
	$layouts = esc_attr(get_post_meta( $post->ID, 'fotography_gallery_layouts', true ));
 	if( $layouts == 'sly') {
		wp_enqueue_script( 'fotography-sly-min-js', get_template_directory_uri() . '/single/js/sly.min.js', array('jquery'), '20150703', true);	
	}
// photoswipe
	wp_enqueue_style('fotography-photoswipe-css',get_template_directory_uri() . '/single/css/photoswipe.css');
	wp_enqueue_style('fotography-default-skin-css',get_template_directory_uri() . '/single/css/default-skin/default-skin.css');
	
	wp_enqueue_script( 'fotography-lightGallery-js', get_template_directory_uri() . '/single/js/lightGallery.js', array('jquery'));
// Photoswipe
	wp_enqueue_script( 'fotography-photoswipe-js', get_template_directory_uri() . '/single/js/photoswipe.js', array('jquery'), '20150731', true);
	wp_enqueue_script( 'fotography-photoswipe-ui-default-min-js', get_template_directory_uri() . '/single/js/photoswipe-ui-default.min.js', array('jquery'), '20150731', true);
	wp_enqueue_script( 'fotography-single-custom-js', get_template_directory_uri() . '/single/js/custom.js');
}

}
add_action( 'wp_enqueue_scripts', 'fotography_scripts' );


function fotography_sly_gallery_layout(){
	global $post;
	$layouts = esc_attr(get_post_meta( $post->ID, 'fotography_gallery_layouts', true ));
 	if( $layouts == 'sly') {
	?>
		<script type="text/javascript">
			/*global Sly */
			jQuery(document).ready(function ($) {
				'use strict';
				document.getElementsByTagName('html')[0].className += ' ' +
					(~window.navigator.userAgent.indexOf('MSIE') ? 'ie' : 'no-ie');
				var $example = $('#example');
				var $frame = $example.find('.frame'); window.frr = $frame;
				var sly = new Sly($frame, {
					horizontal: 1,
				      itemNav: 'centered',
				      smart: 1,
				      activateOn: 'click',
				      activateMiddle: 1,
				      mouseDragging: 1,
				      touchDragging: 1,
				      releaseSwing: 1,
				      startAt: 0,
				      scrollBar: $example.find('.scrollbar'),
					  scrollBy: 1,
					  pagesBar: $example.find('.pages'),
					  activatePageOn: 'click',
				      speed: 50,
				      elasticBounds: 1,
				      easing: 'easeOutExpo',
				      dragHandle: 1,
				      dynamicHandle: 1,
				      clickBar: 1,
				      keyboardNavBy: 0,
					// Buttons
					forward: $example.find('.forward'),
					backward: $example.find('.backward'),
					prev: $example.find('.prev'),
					next: $example.find('.next'),
					prevPage: $example.find('.prevPage'),
					nextPage: $example.find('.nextPage')
				}).init();
				// Method calling buttons
				$example.on('click', 'button[data-action]', function () {
					var action = $(this).data('action');
					switch (action) {
						case 'add':
							sly.add('<li>' + sly.items.length + '</li>');
							break;
						case 'remove':
							sly.remove(-1);
							break;
						default:
							sly[action]();
					}
				});
			});
		</script>
	<?php
	}
}
add_action('wp_footer','fotography_sly_gallery_layout');

/* ==============================CUSTOM CSS================================ */
function fotography_custom_stylesheet(){
	$custom_css = get_theme_mod('fotography_css_section');
	if (!empty($custom_css)) {
	?>
		<style type="text/css">
			<?php echo $custom_css; ?>
		</style>
	<?php 
	}
}
add_action('wp_head','fotography_custom_stylesheet');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Implement the custom metabox feature
 */
require get_template_directory() . '/inc/fotography-functions.php';

/******************************* Video Display ***************************************/
function fotography_get_first_embed_media($post_id) {
    $post = get_post($post_id);
    $content = do_shortcode( apply_filters( 'the_content', $post->post_content ) );
    $embeds = get_media_embedded_in_content( $content, $html = false );
    if( !empty($embeds) ) {
        foreach( $embeds as $embed ) {
            if( strpos( $embed, 'video' ) || strpos( $embed, 'youtube' ) || strpos( $embed, 'vimeo' ) ) {
                return $embed;
            }
        }
    } else {
        return false;
    }
}

/******************************* Pagination ***************************************/
function pagination($pages = '', $range = 2){  
     $showitems = ($range * 2)+1;  
      global $paged;
     if(empty($paged)) $paged = 1; 
     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }   
 
     if(1 != $pages)
     {
         echo "<div class=\"pagination\"><span>Page ".$paged." of ".$pages."</span>";
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>&laquo; First</a>";
          if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo; Previous</a>";
  
          for ($i=1; $i <= $pages; $i++)
          {
              if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
              {
                  echo ($paged == $i)? "<span class=\"current\">".$i."</span>":"<a href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a>";
              }
          }
  
          if ($paged < $pages && $showitems < $pages) echo "<a href=\"".get_pagenum_link($paged + 1)."\">Next &rsaquo;</a>";  
          if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>Last &raquo;</a>";
          echo "</div>\n";
      }
 }

 /**
 * @param string $code name of the shortcode
 * @param string $content
 * @return string content with shortcode striped
 */
function fotography_strip_shortcode($code, $content){
    global $shortcode_tags;
    $stack = $shortcode_tags;
    $shortcode_tags = array($code => 1);
    $content = strip_shortcodes($content);
    $shortcode_tags = $stack;
    return $content;
}

/* Convert hexdec color string to rgb(a) string */
 
function hex2rgba($color, $opacity = false) { 
	 $default = 'rgb(0,0,0)'; 
	 //Return default if no color provided
	 if(empty($color))
	          return $default;  
	 //Sanitize $color if "#" is provided 	
        if ($color[0] == '#' ) {
         $color = substr( $color, 1 );
        }
 
        //Check if color has 6 or 3 characters and get values
        if (strlen($color) == 6) {
                $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
        } elseif ( strlen( $color ) == 3 ) {
                $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
        } else {
                return $default;
        }
 
        //Convert hexadec to rgb
        $rgb =  array_map('hexdec', $hex);
 
        //Check if opacity is set(rgba or rgb)
        if($opacity){
         if(abs($opacity) > 1)
         $opacity = 1.0;
         $output = 'rgba('.implode(",",$rgb).','.$opacity.')';
        } else {
         $output = 'rgb('.implode(",",$rgb).')';
        }
 
        //Return rgb(a) color string
        return $output;
}